@@ -83,12 +83,3 @@ class Application:
             else:
                 raise Exception('error: application is not the top window!')
         raise Exception('timeout: not found that item!')
-
-    def get_rotation(self):
-        self.device.refresh_layout()
-        selector = etree.XML(self.device.xmlStr.encode('utf-8'))
-        if selector.get("sopId") == self.sopId:
-            i = selector.get("rotation")
-            return i
-        else:
-            raise Exception('error: application is not the top window!')
